@@ -4,8 +4,6 @@ import inspect
 import itertools
 import functools
 
-import yaml
-
 from ioc import provider
 from ioc import schema
 from ioc.requirement import DeclaredRequirement
@@ -16,6 +14,7 @@ from ioc.exc import MissingDependencies
 from ioc.pkg import setup
 from ioc.pkg import teardown
 from ioc.provider import get_unsatisfied_dependencies
+from . import etc
 
 
 __version__ = '1.3.11'
@@ -39,8 +38,19 @@ def require(names, *args, **kwargs):
     return DeclaredRequirement(provider, names, *args, **kwargs)
 
 
-def provide(name, value, force=False, tags=None):
-    """Register a Python object as a dependency under the key `name`."""
+def provide(
+    name: str,
+    value: object,
+    force: bool = False,
+    tags: list = None
+) -> object:
+    """Register Python object `value` as a dependency under the key `name` and
+    return the object.
+
+    The `force` argument indicates if any existing dependency under `name`
+    must be overwrriten. If `force` is ``False``, an exception is raised if
+    `name` is already provided.
+    """
     provider.register(name, value, force=force, tags=tags)
     return value
 
@@ -58,15 +68,30 @@ def load(dependencies, override=False):
     s.resolve(schema.Resolver())
 
 
-def load_config(filenames=['etc/ioc.conf', 'etc/ioc.conf.d/*'], override=True):
+def load_config(
+    filenames: list = ['etc/ioc.conf', 'etc/ioc.conf.d/*'],
+    override: bool = True
+):
+    """Configure dependencies from the given configuration files. The
+    `filenames` parameter is a list of string containing the files to read
+    the dependency configuration from, in the specified order.
+
+    The `override` parameter indicates if existing dependencies must be
+    overridden (instead of raising an error on observation on the first
+    duplicate). If `override` is ``False`` and the files specified by the
+    `filename` parameter contain duplicate dependency declarations, then the
+    invocation will always fail.
+    """
     if isinstance(filenames, str):
         filenames = [filenames]
     for filepath in itertools.chain(*[glob.glob(x) for x in filenames]):
-        with open(filepath) as f:
-            load(yaml.safe_load(f.read()), override=override)
+        load(etc.read(filepath), override=override)
 
 
-def is_satisfied(name):
+def is_satisfied(name: str) -> bool:
+    """Return a boolean indicating if the dependency specified by `name`
+    is satisfied.
+    """
     return provider.is_satisfied(name)
 
 
@@ -88,19 +113,42 @@ class class_property(object):
         return self.factory(self.dep)
 
 
-def context(*args, **kwargs):
-    """Shorthand for :meth:`ioc.inject.context`."""
-    return inject.context(*args, **kwargs)
+def context(name: str, injected: object):
+    """Like :func:`inject`, but determine if the :term:`Dependency` is a
+    context-manager. In that case, run the decorated function within a
+    context (e.g. using ``with`` or ``async with``).
+    """
+    return _inject.context(name, injected)
 
 
-class inject:
+def inject(name: str, injected: object, scope: str = 'process'):
     """Ensures that `injected` is made available under
     `name`.
 
+    If the decorated object is a *function*, then `injected` is appended to the
+    function signature e.g.:
+
+    .. code:: python
+
+        import ioc
+
+        ioc.provide('ExampleDependency', 'This is injected into the signature.')
+
+        @ioc.inject('dep', 'ExampleDependency')
+        def f(a, b, dep):
+            return a, b, dep
+
+    The function `f()` may then be invoked by providing the `a` and `b`
+    arguments; the `dep` argument is injected by the framework.
+
     For decorated classes, this implies that the decorator
     sets an attribute `name` on the class with a
     :class:`class_property` instance pointing to `injected`.
     """
+    return _inject(name, injected, scope)
+
+
+class _inject:
 
     @classmethod
     def context(cls, name, injected):
