@@ -18,6 +18,13 @@ class UnsatisfiedDependency(LookupError):
     pass
 
 
+class MissingDependencies(Exception):
+    """The :exc:`MissingDependencies` exception is raised when there are
+    dependencies not injected.
+    """
+    pass
+
+
 class EnvironmentVariableNotDefined(EnvironmentError):
     """Raises when an environment variable does not exist."""
     pass
